package com.ruoyi.mall.service;

import com.ruoyi.mall.domain.MallSchoolScenery;

import java.util.List;

/**
 * 学校风景Service接口
 *
 * @author Lsm
 * @date 2023-10-18
 */
public interface IMallSchoolSceneryService
{
    /**
     * 查询学校风景
     *
     * @param sceneryId 学校风景主键
     * @return 学校风景
     */
    public MallSchoolScenery selectMallSchoolSceneryBySceneryId(Long sceneryId);

    /**
     * 查询学校风景列表
     *
     * @param mallSchoolScenery 学校风景
     * @return 学校风景集合
     */
    public List<MallSchoolScenery> selectMallSchoolSceneryList(MallSchoolScenery mallSchoolScenery);

    /**
     * 新增学校风景
     *
     * @param mallSchoolScenery 学校风景
     * @return 结果
     */
    public int insertMallSchoolScenery(MallSchoolScenery mallSchoolScenery);

    /**
     * 修改学校风景
     *
     * @param mallSchoolScenery 学校风景
     * @return 结果
     */
    public int updateMallSchoolScenery(MallSchoolScenery mallSchoolScenery);

    /**
     * 批量删除学校风景
     *
     * @param sceneryIds 需要删除的学校风景主键集合
     * @return 结果
     */
    public int deleteMallSchoolSceneryBySceneryIds(Long[] sceneryIds);

    /**
     * 删除学校风景信息
     *
     * @param sceneryId 学校风景主键
     * @return 结果
     */
    public int deleteMallSchoolSceneryBySceneryId(Long sceneryId);
}
